# -*- coding: utf-8 -*-

import requests
import json


## Only if status is Open (OP) or Pending (PE)
def cancel_payment(**kwargs):


    item = {
        'integration_key': kwargs.get('key'),
        'hash': kwargs.get('hash')
    }

    send = requests.post(kwargs.get('url')['cancel'], data=item)

    r = send.json()

    return r


# -*- coding: utf-8 -*-

import requests
import json


def new_payment(**kwargs):

    item = {
            'integration_key': kwargs.get('key'),
            'operation': "request",
            'payment': {
                'name': kwargs.get('name'),
                'document': kwargs.get('document'),
                'email': kwargs.get('email'),
                'address': kwargs.get('address'),
                'street_number': kwargs.get('number'),
                'phone_number': kwargs.get('phone'),
                'city': kwargs.get('city'),
                'state': kwargs.get('state'),
                'country': kwargs.get('country'),
                'zipcode': kwargs.get('zipcode'),
                'merchant_payment_code': kwargs.get('payment_code'),
                'currency_code': kwargs.get('currency'),
                'amount_total': kwargs.get('total')
            }
        }

    if kwargs.get('person') == 'business':
            if kwargs.get('responsible') == None:
                return 'Please inform the responsible'
            item['payment']['person_type'] = 'business'
            item['payment']['responsible'] = {}
            item['payment']['responsible']['name'] = kwargs.get('responsible')

    if kwargs.get('type_payment') == 'boleto':
        item['payment']['payment_type_code'] = 'boleto'
        

    ## Check if payment is creditcard!
    if kwargs.get('type_payment') == 'credicard':
        item['payment']['customer_ip'] = kwargs.get('ip') if kwargs.get('ip') else None
        item['payment']['create_token'] = kwargs.get('create_token') if kwargs.get('create_token') else False
        if kwargs.get('token'):
            if item['payment']['create_token'] == False:
                return 'Please set create_token = True'
            else:
                item['payment']['token'] = kwargs.get('token')
        item['payment']['payment_type_code'] = kwargs.get('card_type')
        item['payment']['instalments'] = kwargs.get('instalments') if kwargs.get('instalments') else 1
        item['payment']['creditcard'] = {}
        item['payment']['creditcard']['card_number'] = kwargs.get('card_number')
        item['payment']['creditcard']['card_name'] = kwargs.get('card_name')
        item['payment']['creditcard']['card_due_date'] = kwargs.get('card_due_date')
        item['payment']['creditcard']['card_cvv'] = kwargs.get('cvv')



    request_body = json.dumps(item)

    send = requests.post(kwargs.get('url')['direct'], data=request_body)

    r = send.json()

    return r




# -*- coding: utf-8 -*-

from .request_payment import *
from .request_refund import *
from .cancel_payment import *

class Config:
    def __init__(self, key, mode, gateway):
        self.key = key
        self.modo = mode
        self.gateway = gateway

        self.url = {
            'direct' : 'https://api.ebanx.com.br/ws/direct',
            'capture' : 'https://api.ebanx.com.br/ws/capture',
            'cancel' : 'https://api.ebanx.com.br/ws/cancel',
            'refund': 'https://api.ebanx.com.br/ws/refund',
            'refundOrCancel' : 'https://api.ebanx.com.br/ws/refundOrCancel',
            'setCVV' : 'https://api.ebanx.com.br/ws/token/setCVV',
            'token' : 'https://api.ebanx.com.br/ws/token',
            'query' : 'https://api.ebanx.com.br/ws/query',
            'print' : 'https://api.ebanx.com.br/print'
        }

        if self.modo == 1:


            ### Sandbox
            self.url = {
                'direct' : 'https://staging.ebanx.com.br/ws/direct',
                'capture' : 'https://staging.ebanx.com.br/ws/capture',
                'cancel' : 'https://staging.ebanx.com.br/ws/cancel',
                'refund': 'https://staging.ebanx.com.br/ws/refund',
                'refundOrCancel' : 'https://staging.ebanx.com.br/ws/refundOrCancel',
                'setCVV' : 'https://staging.ebanx.com.br/ws/token/setCVV',
                'token' : 'https://staging.ebanx.com.br/ws/token',
                'query' : 'https://staging.ebanx.com.br/ws/query',
                'print' : 'https://staging.ebanx.com.br/print'
                
            }

    def send(self,**kwargs):

        new = new_payment(key=self.key,url=self.url,**kwargs)

        return new
    
    def cancel(self,**kwargs):

        new = cancel_payment(key=self.key,url=self.url,**kwargs)

        return new

    def refund(self,**kwargs):

        new = new_payment(key=self.key,url=self.url,**kwargs)

        return new

    def refund_or_cancel(self,**kwargs):

        new = new_refund_or_cancel(key=self.key,url=self.url,**kwargs)

        return new

    def new_cancel_refund(self,**kwargs):

        new = new_cancel_refund(key=self.key,url=self.url,**kwargs)

        return new


from setuptools import setup


requires = [
    'requests>=2.21.0'
]


setup(
    name='pypayments',
    packages=['pypayments'],  # this must be the same as the name above
    version='0.2.3',
    description='Unofficial library for make payments in Python',
    author='Daniel Guilhermino',
    author_email='daniel@hubtec.com.br',
    license='MIT',
    url='https://github.com/hubtec/pypayments',
    keywords=['ebanx', 'payments', 'gateway'],
    classifiers=[],
)



# -*- coding: utf-8 -*-

import requests
import json


def refund(**kwargs):

    item = {
        'integration_key': kwargs.get('key'),
        'merchant_refund_code': kwargs.get('refund_code'),
        'operation': "request",
        'amount':kwargs.get('total'),
        'hash': kwargs.get('hash'),
        'description': kwargs.get('description')
    }

    send = requests.post(kwargs.get('url')['refund'], data=item)

    r = send.json()

    return r


def new_refund_or_cancel(**kwargs):

    item = {
        'integration_key': kwargs.get('key'),
        'merchant_refund_code': kwargs.get('refund_code'),
        'operation': "request",
        'amount':kwargs.get('total'),
        'hash': kwargs.get('hash'),
        'description': kwargs.get('description')
    }

    send = requests.post(kwargs.get('url')['refund'], data=item)

    r = send.json()

    return r


def new_cancel_refund(**kwargs):

    item = {
        'integration_key': kwargs.get('key'),
        'merchant_refund_code': kwargs.get('refund_code'),
        'operation': "cancel"
    }

    send = requests.post(kwargs.get('url')['refund'], data=item)

    r = send.json()

    return r